# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cardpay.model.next_subscription_payment import (
    NextSubscriptionPayment,
)  # noqa: F401,E501
from cardpay.model.payout_response_customer import (
    PayoutResponseCustomer,
)  # noqa: F401,E501
from cardpay.model.plan import Plan  # noqa: F401,E501


class SubscriptionGetResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "amount_due": "float",
        "amount_total": "float",
        "created": "datetime",
        "currency": "str",
        "customer": "PayoutResponseCustomer",
        "description": "str",
        "id": "str",
        "interval": "int",
        "next_payment": "NextSubscriptionPayment",
        "payments_due": "int",
        "period": "str",
        "plan": "Plan",
        "retries": "int",
        "status": "str",
        "status_reason": "str",
        "subscription_start": "datetime",
        "type": "str",
    }

    attribute_map = {
        "amount_due": "amount_due",
        "amount_total": "amount_total",
        "created": "created",
        "currency": "currency",
        "customer": "customer",
        "description": "description",
        "id": "id",
        "interval": "interval",
        "next_payment": "next_payment",
        "payments_due": "payments_due",
        "period": "period",
        "plan": "plan",
        "retries": "retries",
        "status": "status",
        "status_reason": "status_reason",
        "subscription_start": "subscription_start",
        "type": "type",
    }

    def __init__(
        self,
        amount_due=None,
        amount_total=None,
        created=None,
        currency=None,
        customer=None,
        description=None,
        id=None,
        interval=None,
        next_payment=None,
        payments_due=None,
        period=None,
        plan=None,
        retries=None,
        status=None,
        status_reason=None,
        subscription_start=None,
        type=None,
    ):  # noqa: E501
        """SubscriptionGetResponse - a model defined in Swagger"""  # noqa: E501

        self._amount_due = None
        self._amount_total = None
        self._created = None
        self._currency = None
        self._customer = None
        self._description = None
        self._id = None
        self._interval = None
        self._next_payment = None
        self._payments_due = None
        self._period = None
        self._plan = None
        self._retries = None
        self._status = None
        self._status_reason = None
        self._subscription_start = None
        self._type = None
        self.discriminator = None

        if amount_due is not None:
            self.amount_due = amount_due
        if amount_total is not None:
            self.amount_total = amount_total
        if created is not None:
            self.created = created
        if currency is not None:
            self.currency = currency
        if customer is not None:
            self.customer = customer
        if description is not None:
            self.description = description
        if id is not None:
            self.id = id
        if interval is not None:
            self.interval = interval
        if next_payment is not None:
            self.next_payment = next_payment
        if payments_due is not None:
            self.payments_due = payments_due
        if period is not None:
            self.period = period
        if plan is not None:
            self.plan = plan
        if retries is not None:
            self.retries = retries
        if status is not None:
            self.status = status
        if status_reason is not None:
            self.status_reason = status_reason
        if subscription_start is not None:
            self.subscription_start = subscription_start
        if type is not None:
            self.type = type

    @property
    def amount_due(self):
        """Gets the amount_due of this SubscriptionGetResponse.  # noqa: E501

        Amount of payments left to be captured  # noqa: E501

        :return: The amount_due of this SubscriptionGetResponse.  # noqa: E501
        :rtype: float
        """
        return self._amount_due

    @amount_due.setter
    def amount_due(self, amount_due):
        """Sets the amount_due of this SubscriptionGetResponse.

        Amount of payments left to be captured  # noqa: E501

        :param amount_due: The amount_due of this SubscriptionGetResponse.  # noqa: E501
        :type: float
        """

        self._amount_due = amount_due

    @property
    def amount_total(self):
        """Gets the amount_total of this SubscriptionGetResponse.  # noqa: E501

        Total amount of subscription to be paid before completion  # noqa: E501

        :return: The amount_total of this SubscriptionGetResponse.  # noqa: E501
        :rtype: float
        """
        return self._amount_total

    @amount_total.setter
    def amount_total(self, amount_total):
        """Sets the amount_total of this SubscriptionGetResponse.

        Total amount of subscription to be paid before completion  # noqa: E501

        :param amount_total: The amount_total of this SubscriptionGetResponse.  # noqa: E501
        :type: float
        """

        self._amount_total = amount_total

    @property
    def created(self):
        """Gets the created of this SubscriptionGetResponse.  # noqa: E501

        Creation time [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format  # noqa: E501

        :return: The created of this SubscriptionGetResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this SubscriptionGetResponse.

        Creation time [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format  # noqa: E501

        :param created: The created of this SubscriptionGetResponse.  # noqa: E501
        :type: datetime
        """

        self._created = created

    @property
    def currency(self):
        """Gets the currency of this SubscriptionGetResponse.  # noqa: E501

        [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217) currency code  # noqa: E501

        :return: The currency of this SubscriptionGetResponse.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this SubscriptionGetResponse.

        [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217) currency code  # noqa: E501

        :param currency: The currency of this SubscriptionGetResponse.  # noqa: E501
        :type: str
        """

        self._currency = currency

    @property
    def customer(self):
        """Gets the customer of this SubscriptionGetResponse.  # noqa: E501

        Customer data  # noqa: E501

        :return: The customer of this SubscriptionGetResponse.  # noqa: E501
        :rtype: PayoutResponseCustomer
        """
        return self._customer

    @customer.setter
    def customer(self, customer):
        """Sets the customer of this SubscriptionGetResponse.

        Customer data  # noqa: E501

        :param customer: The customer of this SubscriptionGetResponse.  # noqa: E501
        :type: PayoutResponseCustomer
        """

        self._customer = customer

    @property
    def description(self):
        """Gets the description of this SubscriptionGetResponse.  # noqa: E501

        Description of subscription  # noqa: E501

        :return: The description of this SubscriptionGetResponse.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this SubscriptionGetResponse.

        Description of subscription  # noqa: E501

        :param description: The description of this SubscriptionGetResponse.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def id(self):
        """Gets the id of this SubscriptionGetResponse.  # noqa: E501

        ID of subscription  # noqa: E501

        :return: The id of this SubscriptionGetResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SubscriptionGetResponse.

        ID of subscription  # noqa: E501

        :param id: The id of this SubscriptionGetResponse.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def interval(self):
        """Gets the interval of this SubscriptionGetResponse.  # noqa: E501

        Interval of subscription  # noqa: E501

        :return: The interval of this SubscriptionGetResponse.  # noqa: E501
        :rtype: int
        """
        return self._interval

    @interval.setter
    def interval(self, interval):
        """Sets the interval of this SubscriptionGetResponse.

        Interval of subscription  # noqa: E501

        :param interval: The interval of this SubscriptionGetResponse.  # noqa: E501
        :type: int
        """

        self._interval = interval

    @property
    def next_payment(self):
        """Gets the next_payment of this SubscriptionGetResponse.  # noqa: E501

        Next payment data  # noqa: E501

        :return: The next_payment of this SubscriptionGetResponse.  # noqa: E501
        :rtype: NextSubscriptionPayment
        """
        return self._next_payment

    @next_payment.setter
    def next_payment(self, next_payment):
        """Sets the next_payment of this SubscriptionGetResponse.

        Next payment data  # noqa: E501

        :param next_payment: The next_payment of this SubscriptionGetResponse.  # noqa: E501
        :type: NextSubscriptionPayment
        """

        self._next_payment = next_payment

    @property
    def payments_due(self):
        """Gets the payments_due of this SubscriptionGetResponse.  # noqa: E501

        Number of payments left to be captured  # noqa: E501

        :return: The payments_due of this SubscriptionGetResponse.  # noqa: E501
        :rtype: int
        """
        return self._payments_due

    @payments_due.setter
    def payments_due(self, payments_due):
        """Sets the payments_due of this SubscriptionGetResponse.

        Number of payments left to be captured  # noqa: E501

        :param payments_due: The payments_due of this SubscriptionGetResponse.  # noqa: E501
        :type: int
        """

        self._payments_due = payments_due

    class Period(object):
        MINUTE = "minute"
        DAY = "day"
        WEEK = "week"
        MONTH = "month"
        YEAR = "year"

    @property
    def period(self):
        """Gets the period of this SubscriptionGetResponse.  # noqa: E501

        Period of subscription  # noqa: E501

        :return: The period of this SubscriptionGetResponse.  # noqa: E501
        :rtype: str
        """
        return self._period

    @period.setter
    def period(self, period):
        """Sets the period of this SubscriptionGetResponse.

        Period of subscription  # noqa: E501

        :param period: The period of this SubscriptionGetResponse.  # noqa: E501
        :type: str
        """
        allowed_values = ["minute", "day", "week", "month", "year"]  # noqa: E501
        if period not in allowed_values:
            raise ValueError(
                "Invalid value for `period` ({0}), must be one of {1}".format(  # noqa: E501
                    period, allowed_values
                )
            )

        self._period = period

    @property
    def plan(self):
        """Gets the plan of this SubscriptionGetResponse.  # noqa: E501

        Plan data  # noqa: E501

        :return: The plan of this SubscriptionGetResponse.  # noqa: E501
        :rtype: Plan
        """
        return self._plan

    @plan.setter
    def plan(self, plan):
        """Sets the plan of this SubscriptionGetResponse.

        Plan data  # noqa: E501

        :param plan: The plan of this SubscriptionGetResponse.  # noqa: E501
        :type: Plan
        """

        self._plan = plan

    @property
    def retries(self):
        """Gets the retries of this SubscriptionGetResponse.  # noqa: E501

        Number of daily basis retry attempts in case of payment has not been captured successfully.  # noqa: E501

        :return: The retries of this SubscriptionGetResponse.  # noqa: E501
        :rtype: int
        """
        return self._retries

    @retries.setter
    def retries(self, retries):
        """Sets the retries of this SubscriptionGetResponse.

        Number of daily basis retry attempts in case of payment has not been captured successfully.  # noqa: E501

        :param retries: The retries of this SubscriptionGetResponse.  # noqa: E501
        :type: int
        """

        self._retries = retries

    class Status(object):
        ACTIVE = "ACTIVE"
        INACTIVE = "INACTIVE"
        CANCELLED = "CANCELLED"
        PAST_DUE = "PAST_DUE"
        PENDING = "PENDING"
        COMPLETED = "COMPLETED"
        CARD_EXPIRED = "CARD_EXPIRED"
        ACTIVATION_FAILED = "ACTIVATION_FAILED"

    @property
    def status(self):
        """Gets the status of this SubscriptionGetResponse.  # noqa: E501

        Status of subscription  # noqa: E501

        :return: The status of this SubscriptionGetResponse.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this SubscriptionGetResponse.

        Status of subscription  # noqa: E501

        :param status: The status of this SubscriptionGetResponse.  # noqa: E501
        :type: str
        """
        allowed_values = [
            "ACTIVE",
            "INACTIVE",
            "CANCELLED",
            "PAST_DUE",
            "PENDING",
            "COMPLETED",
            "CARD_EXPIRED",
            "ACTIVATION_FAILED",
        ]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}".format(  # noqa: E501
                    status, allowed_values
                )
            )

        self._status = status

    @property
    def status_reason(self):
        """Gets the status_reason of this SubscriptionGetResponse.  # noqa: E501

        Reason of subscription cancellation that was made by CardPay  # noqa: E501

        :return: The status_reason of this SubscriptionGetResponse.  # noqa: E501
        :rtype: str
        """
        return self._status_reason

    @status_reason.setter
    def status_reason(self, status_reason):
        """Sets the status_reason of this SubscriptionGetResponse.

        Reason of subscription cancellation that was made by CardPay  # noqa: E501

        :param status_reason: The status_reason of this SubscriptionGetResponse.  # noqa: E501
        :type: str
        """

        self._status_reason = status_reason

    @property
    def subscription_start(self):
        """Gets the subscription_start of this SubscriptionGetResponse.  # noqa: E501

        The time in 'yyyy-MM-dd' format when subscription actually becomes activated (grace period)  # noqa: E501

        :return: The subscription_start of this SubscriptionGetResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._subscription_start

    @subscription_start.setter
    def subscription_start(self, subscription_start):
        """Sets the subscription_start of this SubscriptionGetResponse.

        The time in 'yyyy-MM-dd' format when subscription actually becomes activated (grace period)  # noqa: E501

        :param subscription_start: The subscription_start of this SubscriptionGetResponse.  # noqa: E501
        :type: datetime
        """

        self._subscription_start = subscription_start

    class Type(object):
        ONECLICK = "ONECLICK"
        SCHEDULED = "SCHEDULED"
        INSTALLMENT = "INSTALLMENT"

    @property
    def type(self):
        """Gets the type of this SubscriptionGetResponse.  # noqa: E501

        Recurring payment type name; can be ONECLICK, SCHEDULED, INSTALLMENT  # noqa: E501

        :return: The type of this SubscriptionGetResponse.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this SubscriptionGetResponse.

        Recurring payment type name; can be ONECLICK, SCHEDULED, INSTALLMENT  # noqa: E501

        :param type: The type of this SubscriptionGetResponse.  # noqa: E501
        :type: str
        """
        allowed_values = ["ONECLICK", "SCHEDULED", "INSTALLMENT"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}".format(  # noqa: E501
                    type, allowed_values
                )
            )

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(SubscriptionGetResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SubscriptionGetResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cardpay.model.request import Request  # noqa: F401,E501
from cardpay.model.request_updated_transaction_data import (
    RequestUpdatedTransactionData,
)  # noqa: F401,E501


class TransactionUpdateRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "request": "Request",
        "transaction_data": "RequestUpdatedTransactionData",
    }

    attribute_map = {"request": "request", "transaction_data": "transaction_data"}

    def __init__(self, request=None, transaction_data=None):  # noqa: E501
        """TransactionUpdateRequest - a model defined in Swagger"""  # noqa: E501

        self._request = None
        self._transaction_data = None
        self.discriminator = None

        self.request = request
        if transaction_data is not None:
            self.transaction_data = transaction_data

    @property
    def request(self):
        """Gets the request of this TransactionUpdateRequest.  # noqa: E501

        Request  # noqa: E501

        :return: The request of this TransactionUpdateRequest.  # noqa: E501
        :rtype: Request
        """
        return self._request

    @request.setter
    def request(self, request):
        """Sets the request of this TransactionUpdateRequest.

        Request  # noqa: E501

        :param request: The request of this TransactionUpdateRequest.  # noqa: E501
        :type: Request
        """
        if request is None:
            raise ValueError(
                "Invalid value for `request`, must not be `None`"
            )  # noqa: E501

        self._request = request

    @property
    def transaction_data(self):
        """Gets the transaction_data of this TransactionUpdateRequest.  # noqa: E501

        Transaction data  # noqa: E501

        :return: The transaction_data of this TransactionUpdateRequest.  # noqa: E501
        :rtype: RequestUpdatedTransactionData
        """
        return self._transaction_data

    @transaction_data.setter
    def transaction_data(self, transaction_data):
        """Sets the transaction_data of this TransactionUpdateRequest.

        Transaction data  # noqa: E501

        :param transaction_data: The transaction_data of this TransactionUpdateRequest.  # noqa: E501
        :type: RequestUpdatedTransactionData
        """

        self._transaction_data = transaction_data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(TransactionUpdateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TransactionUpdateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class PaymentRequestEWalletAccount(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "bank_code": "str",
        "creation_date": "str",
        "expiration_date": "str",
        "id": "str",
        "verification_code": "str",
    }

    attribute_map = {
        "bank_code": "bank_code",
        "creation_date": "creation_date",
        "expiration_date": "expiration_date",
        "id": "id",
        "verification_code": "verification_code",
    }

    def __init__(
        self,
        bank_code=None,
        creation_date=None,
        expiration_date=None,
        id=None,
        verification_code=None,
    ):  # noqa: E501
        """PaymentRequestEWalletAccount - a model defined in Swagger"""  # noqa: E501

        self._bank_code = None
        self._creation_date = None
        self._expiration_date = None
        self._id = None
        self._verification_code = None
        self.discriminator = None

        if bank_code is not None:
            self.bank_code = bank_code
        if creation_date is not None:
            self.creation_date = creation_date
        if expiration_date is not None:
            self.expiration_date = expiration_date
        if id is not None:
            self.id = id
        if verification_code is not None:
            self.verification_code = verification_code

    @property
    def bank_code(self):
        """Gets the bank_code of this PaymentRequestEWalletAccount.  # noqa: E501

        Card issuer's code. For DIRECTBANKINGNGA: Customer bank code (3 digits). Mandatory for DIRECTBANKINGNGA payment method only.  # noqa: E501

        :return: The bank_code of this PaymentRequestEWalletAccount.  # noqa: E501
        :rtype: str
        """
        return self._bank_code

    @bank_code.setter
    def bank_code(self, bank_code):
        """Sets the bank_code of this PaymentRequestEWalletAccount.

        Card issuer's code. For DIRECTBANKINGNGA: Customer bank code (3 digits). Mandatory for DIRECTBANKINGNGA payment method only.  # noqa: E501

        :param bank_code: The bank_code of this PaymentRequestEWalletAccount.  # noqa: E501
        :type: str
        """

        self._bank_code = bank_code

    @property
    def creation_date(self):
        """Gets the creation_date of this PaymentRequestEWalletAccount.  # noqa: E501

        Card creation date  # noqa: E501

        :return: The creation_date of this PaymentRequestEWalletAccount.  # noqa: E501
        :rtype: str
        """
        return self._creation_date

    @creation_date.setter
    def creation_date(self, creation_date):
        """Sets the creation_date of this PaymentRequestEWalletAccount.

        Card creation date  # noqa: E501

        :param creation_date: The creation_date of this PaymentRequestEWalletAccount.  # noqa: E501
        :type: str
        """
        if creation_date is not None and not re.search(
            r"^[\\d{2,4}|\/?|\\.?]{2,10}$", creation_date
        ):  # noqa: E501
            raise ValueError(
                r"Invalid value for `creation_date`, must be a follow pattern or equal to `/^[\\d{2,4}|\/?|\\.?]{2,10}$/`"
            )  # noqa: E501

        self._creation_date = creation_date

    @property
    def expiration_date(self):
        """Gets the expiration_date of this PaymentRequestEWalletAccount.  # noqa: E501

        Account expiration date  # noqa: E501

        :return: The expiration_date of this PaymentRequestEWalletAccount.  # noqa: E501
        :rtype: str
        """
        return self._expiration_date

    @expiration_date.setter
    def expiration_date(self, expiration_date):
        """Sets the expiration_date of this PaymentRequestEWalletAccount.

        Account expiration date  # noqa: E501

        :param expiration_date: The expiration_date of this PaymentRequestEWalletAccount.  # noqa: E501
        :type: str
        """
        if expiration_date is not None and not re.search(
            r"^[\\d{2,4}|\/?|\\.?]{2,10}$", expiration_date
        ):  # noqa: E501
            raise ValueError(
                r"Invalid value for `expiration_date`, must be a follow pattern or equal to `/^[\\d{2,4}|\/?|\\.?]{2,10}$/`"
            )  # noqa: E501

        self._expiration_date = expiration_date

    @property
    def id(self):
        """Gets the id of this PaymentRequestEWalletAccount.  # noqa: E501

        For QIWI: Customer phone number (from 1 to 15 digits). For NETELLER: email address of Customer. For 'Latin America': Customer personal identification number: CPF or CNPJ for Brazil, DNI for Argentina and ID for other countries. For AIRTEL, MPESA, MTN, UGANDAMOBILE, VODAFONE and TIGO: phone number linked to Customer's mobile money account. For DIRECTBANKINGNGA: bank account number Mandatory for QIWI, NETELLER, 'Latin America', AIRTEL, MPESA, MTN, UGANDAMOBILE, VODAFONE, TIGO and DIRECTBANKINGNGA payment methods only.  # noqa: E501

        :return: The id of this PaymentRequestEWalletAccount.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PaymentRequestEWalletAccount.

        For QIWI: Customer phone number (from 1 to 15 digits). For NETELLER: email address of Customer. For 'Latin America': Customer personal identification number: CPF or CNPJ for Brazil, DNI for Argentina and ID for other countries. For AIRTEL, MPESA, MTN, UGANDAMOBILE, VODAFONE and TIGO: phone number linked to Customer's mobile money account. For DIRECTBANKINGNGA: bank account number Mandatory for QIWI, NETELLER, 'Latin America', AIRTEL, MPESA, MTN, UGANDAMOBILE, VODAFONE, TIGO and DIRECTBANKINGNGA payment methods only.  # noqa: E501

        :param id: The id of this PaymentRequestEWalletAccount.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def verification_code(self):
        """Gets the verification_code of this PaymentRequestEWalletAccount.  # noqa: E501

        Provider security code. For NETELLER: member's 6 digits Secure Id or Google Authenticator OTP For VODAFONE: Customer voucher code (6 digits) For UBA bank in DIRECTBANKINGNGA: Customer BVN (bank verification number) number, 11 digits Mandatory for NETELLER, VODAFONE and DIRECTBANKINGNGA payment methods only.  # noqa: E501

        :return: The verification_code of this PaymentRequestEWalletAccount.  # noqa: E501
        :rtype: str
        """
        return self._verification_code

    @verification_code.setter
    def verification_code(self, verification_code):
        """Sets the verification_code of this PaymentRequestEWalletAccount.

        Provider security code. For NETELLER: member's 6 digits Secure Id or Google Authenticator OTP For VODAFONE: Customer voucher code (6 digits) For UBA bank in DIRECTBANKINGNGA: Customer BVN (bank verification number) number, 11 digits Mandatory for NETELLER, VODAFONE and DIRECTBANKINGNGA payment methods only.  # noqa: E501

        :param verification_code: The verification_code of this PaymentRequestEWalletAccount.  # noqa: E501
        :type: str
        """

        self._verification_code = verification_code

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(PaymentRequestEWalletAccount, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PaymentRequestEWalletAccount):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class RecurringCustomer(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "email": "str",
        "home_phone": "str",
        "id": "str",
        "ip": "str",
        "locale": "str",
        "phone": "str",
        "work_phone": "str",
    }

    attribute_map = {
        "email": "email",
        "home_phone": "home_phone",
        "id": "id",
        "ip": "ip",
        "locale": "locale",
        "phone": "phone",
        "work_phone": "work_phone",
    }

    def __init__(
        self,
        email=None,
        home_phone=None,
        id=None,
        ip=None,
        locale=None,
        phone=None,
        work_phone=None,
    ):  # noqa: E501
        """RecurringCustomer - a model defined in Swagger"""  # noqa: E501

        self._email = None
        self._home_phone = None
        self._id = None
        self._ip = None
        self._locale = None
        self._phone = None
        self._work_phone = None
        self.discriminator = None

        self.email = email
        if home_phone is not None:
            self.home_phone = home_phone
        self.id = id
        if ip is not None:
            self.ip = ip
        if locale is not None:
            self.locale = locale
        if phone is not None:
            self.phone = phone
        if work_phone is not None:
            self.work_phone = work_phone

    @property
    def email(self):
        """Gets the email of this RecurringCustomer.  # noqa: E501

        Customer's e-mail address. Mandatory by default, can be defined as optional by CardPay manager.  # noqa: E501

        :return: The email of this RecurringCustomer.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this RecurringCustomer.

        Customer's e-mail address. Mandatory by default, can be defined as optional by CardPay manager.  # noqa: E501

        :param email: The email of this RecurringCustomer.  # noqa: E501
        :type: str
        """
        if email is None:
            raise ValueError(
                "Invalid value for `email`, must not be `None`"
            )  # noqa: E501
        if email is not None and len(email) > 256:
            raise ValueError(
                "Invalid value for `email`, length must be less than or equal to `256`"
            )  # noqa: E501
        if email is not None and len(email) < 1:
            raise ValueError(
                "Invalid value for `email`, length must be greater than or equal to `1`"
            )  # noqa: E501

        self._email = email

    @property
    def home_phone(self):
        """Gets the home_phone of this RecurringCustomer.  # noqa: E501

        The work phone number provided by the Cardholder. Required (if available), unless market or regional mandate restricts sending this information. Characters Format: string (10-18 symbols) country code + Subscriber number. Refer to ITU-E.164 for additional information on format and length.  # noqa: E501

        :return: The home_phone of this RecurringCustomer.  # noqa: E501
        :rtype: str
        """
        return self._home_phone

    @home_phone.setter
    def home_phone(self, home_phone):
        """Sets the home_phone of this RecurringCustomer.

        The work phone number provided by the Cardholder. Required (if available), unless market or regional mandate restricts sending this information. Characters Format: string (10-18 symbols) country code + Subscriber number. Refer to ITU-E.164 for additional information on format and length.  # noqa: E501

        :param home_phone: The home_phone of this RecurringCustomer.  # noqa: E501
        :type: str
        """
        if home_phone is not None and len(home_phone) > 18:
            raise ValueError(
                "Invalid value for `home_phone`, length must be less than or equal to `18`"
            )  # noqa: E501
        if home_phone is not None and len(home_phone) < 8:
            raise ValueError(
                "Invalid value for `home_phone`, length must be greater than or equal to `8`"
            )  # noqa: E501

        self._home_phone = home_phone

    @property
    def id(self):
        """Gets the id of this RecurringCustomer.  # noqa: E501

        Customer's ID in Merchant's system  # noqa: E501

        :return: The id of this RecurringCustomer.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this RecurringCustomer.

        Customer's ID in Merchant's system  # noqa: E501

        :param id: The id of this RecurringCustomer.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501
        if id is not None and len(id) > 256:
            raise ValueError(
                "Invalid value for `id`, length must be less than or equal to `256`"
            )  # noqa: E501
        if id is not None and len(id) < 0:
            raise ValueError(
                "Invalid value for `id`, length must be greater than or equal to `0`"
            )  # noqa: E501

        self._id = id

    @property
    def ip(self):
        """Gets the ip of this RecurringCustomer.  # noqa: E501

        Customer IPv4  # noqa: E501

        :return: The ip of this RecurringCustomer.  # noqa: E501
        :rtype: str
        """
        return self._ip

    @ip.setter
    def ip(self, ip):
        """Sets the ip of this RecurringCustomer.

        Customer IPv4  # noqa: E501

        :param ip: The ip of this RecurringCustomer.  # noqa: E501
        :type: str
        """
        if ip is not None and len(ip) > 15:
            raise ValueError(
                "Invalid value for `ip`, length must be less than or equal to `15`"
            )  # noqa: E501
        if ip is not None and len(ip) < 1:
            raise ValueError(
                "Invalid value for `ip`, length must be greater than or equal to `1`"
            )  # noqa: E501

        self._ip = ip

    class Locale(object):
        RU = "ru"
        EN = "en"
        ZH = "zh"
        JA = "ja"

    @property
    def locale(self):
        """Gets the locale of this RecurringCustomer.  # noqa: E501

        Preferred locale for the payment page ([ISO 639-1](https://en.wikipedia.org/wiki/ISO_639-1) language code). The default locale will be applied if the selected locale is not supported. Supported locales are: `ru`, `en`, `zh`, `ja`  # noqa: E501

        :return: The locale of this RecurringCustomer.  # noqa: E501
        :rtype: str
        """
        return self._locale

    @locale.setter
    def locale(self, locale):
        """Sets the locale of this RecurringCustomer.

        Preferred locale for the payment page ([ISO 639-1](https://en.wikipedia.org/wiki/ISO_639-1) language code). The default locale will be applied if the selected locale is not supported. Supported locales are: `ru`, `en`, `zh`, `ja`  # noqa: E501

        :param locale: The locale of this RecurringCustomer.  # noqa: E501
        :type: str
        """
        allowed_values = ["ru", "en", "zh", "ja"]  # noqa: E501
        if locale not in allowed_values:
            raise ValueError(
                "Invalid value for `locale` ({0}), must be one of {1}".format(  # noqa: E501
                    locale, allowed_values
                )
            )

        self._locale = locale

    @property
    def phone(self):
        """Gets the phone of this RecurringCustomer.  # noqa: E501

        Customer phone number. Optional by default, can be defined as mandatory by CardPay manager.  # noqa: E501

        :return: The phone of this RecurringCustomer.  # noqa: E501
        :rtype: str
        """
        return self._phone

    @phone.setter
    def phone(self, phone):
        """Sets the phone of this RecurringCustomer.

        Customer phone number. Optional by default, can be defined as mandatory by CardPay manager.  # noqa: E501

        :param phone: The phone of this RecurringCustomer.  # noqa: E501
        :type: str
        """
        if phone is not None and len(phone) > 18:
            raise ValueError(
                "Invalid value for `phone`, length must be less than or equal to `18`"
            )  # noqa: E501
        if phone is not None and len(phone) < 8:
            raise ValueError(
                "Invalid value for `phone`, length must be greater than or equal to `8`"
            )  # noqa: E501

        self._phone = phone

    @property
    def work_phone(self):
        """Gets the work_phone of this RecurringCustomer.  # noqa: E501

        The home phone number provided by the Cardholder. Required (if available) unless market or regional mandate restricts sending this information. Characters Format: string (10-18 symbols) country code + Subscriber number. Refer to ITU-E.164 for additional information on format and length.  # noqa: E501

        :return: The work_phone of this RecurringCustomer.  # noqa: E501
        :rtype: str
        """
        return self._work_phone

    @work_phone.setter
    def work_phone(self, work_phone):
        """Sets the work_phone of this RecurringCustomer.

        The home phone number provided by the Cardholder. Required (if available) unless market or regional mandate restricts sending this information. Characters Format: string (10-18 symbols) country code + Subscriber number. Refer to ITU-E.164 for additional information on format and length.  # noqa: E501

        :param work_phone: The work_phone of this RecurringCustomer.  # noqa: E501
        :type: str
        """
        if work_phone is not None and len(work_phone) > 18:
            raise ValueError(
                "Invalid value for `work_phone`, length must be less than or equal to `18`"
            )  # noqa: E501
        if work_phone is not None and len(work_phone) < 8:
            raise ValueError(
                "Invalid value for `work_phone`, length must be greater than or equal to `8`"
            )  # noqa: E501

        self._work_phone = work_phone

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(RecurringCustomer, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RecurringCustomer):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class PayoutResponseCard(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {"issuing_country_code": "str", "masked_pan": "str"}

    attribute_map = {
        "issuing_country_code": "issuing_country_code",
        "masked_pan": "masked_pan",
    }

    def __init__(self, issuing_country_code=None, masked_pan=None):  # noqa: E501
        """PayoutResponseCard - a model defined in Swagger"""  # noqa: E501

        self._issuing_country_code = None
        self._masked_pan = None
        self.discriminator = None

        if issuing_country_code is not None:
            self.issuing_country_code = issuing_country_code
        if masked_pan is not None:
            self.masked_pan = masked_pan

    @property
    def issuing_country_code(self):
        """Gets the issuing_country_code of this PayoutResponseCard.  # noqa: E501

        Country code of issuing card country  # noqa: E501

        :return: The issuing_country_code of this PayoutResponseCard.  # noqa: E501
        :rtype: str
        """
        return self._issuing_country_code

    @issuing_country_code.setter
    def issuing_country_code(self, issuing_country_code):
        """Sets the issuing_country_code of this PayoutResponseCard.

        Country code of issuing card country  # noqa: E501

        :param issuing_country_code: The issuing_country_code of this PayoutResponseCard.  # noqa: E501
        :type: str
        """

        self._issuing_country_code = issuing_country_code

    @property
    def masked_pan(self):
        """Gets the masked_pan of this PayoutResponseCard.  # noqa: E501

        Masked PAN (shows first 6 digits and 4 last digits of the PAN)  # noqa: E501

        :return: The masked_pan of this PayoutResponseCard.  # noqa: E501
        :rtype: str
        """
        return self._masked_pan

    @masked_pan.setter
    def masked_pan(self, masked_pan):
        """Sets the masked_pan of this PayoutResponseCard.

        Masked PAN (shows first 6 digits and 4 last digits of the PAN)  # noqa: E501

        :param masked_pan: The masked_pan of this PayoutResponseCard.  # noqa: E501
        :type: str
        """

        self._masked_pan = masked_pan

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(PayoutResponseCard, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PayoutResponseCard):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Flight(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "carrier_code": "str",
        "destination_code": "str",
        "fare_basis_code": "str",
        "index": "int",
        "number": "str",
        "service_class_code": "int",
        "stop_over_code": "str",
    }

    attribute_map = {
        "carrier_code": "carrier_code",
        "destination_code": "destination_code",
        "fare_basis_code": "fare_basis_code",
        "index": "index",
        "number": "number",
        "service_class_code": "service_class_code",
        "stop_over_code": "stop_over_code",
    }

    def __init__(
        self,
        carrier_code=None,
        destination_code=None,
        fare_basis_code=None,
        index=None,
        number=None,
        service_class_code=None,
        stop_over_code=None,
    ):  # noqa: E501
        """Flight - a model defined in Swagger"""  # noqa: E501

        self._carrier_code = None
        self._destination_code = None
        self._fare_basis_code = None
        self._index = None
        self._number = None
        self._service_class_code = None
        self._stop_over_code = None
        self.discriminator = None

        if carrier_code is not None:
            self.carrier_code = carrier_code
        if destination_code is not None:
            self.destination_code = destination_code
        if fare_basis_code is not None:
            self.fare_basis_code = fare_basis_code
        if index is not None:
            self.index = index
        if number is not None:
            self.number = number
        if service_class_code is not None:
            self.service_class_code = service_class_code
        if stop_over_code is not None:
            self.stop_over_code = stop_over_code

    @property
    def carrier_code(self):
        """Gets the carrier_code of this Flight.  # noqa: E501

        Carrier code  # noqa: E501

        :return: The carrier_code of this Flight.  # noqa: E501
        :rtype: str
        """
        return self._carrier_code

    @carrier_code.setter
    def carrier_code(self, carrier_code):
        """Sets the carrier_code of this Flight.

        Carrier code  # noqa: E501

        :param carrier_code: The carrier_code of this Flight.  # noqa: E501
        :type: str
        """
        if carrier_code is not None and len(carrier_code) > 2:
            raise ValueError(
                "Invalid value for `carrier_code`, length must be less than or equal to `2`"
            )  # noqa: E501
        if carrier_code is not None and len(carrier_code) < 2:
            raise ValueError(
                "Invalid value for `carrier_code`, length must be greater than or equal to `2`"
            )  # noqa: E501

        self._carrier_code = carrier_code

    @property
    def destination_code(self):
        """Gets the destination_code of this Flight.  # noqa: E501

        Code of airport of destination, IATA code  # noqa: E501

        :return: The destination_code of this Flight.  # noqa: E501
        :rtype: str
        """
        return self._destination_code

    @destination_code.setter
    def destination_code(self, destination_code):
        """Sets the destination_code of this Flight.

        Code of airport of destination, IATA code  # noqa: E501

        :param destination_code: The destination_code of this Flight.  # noqa: E501
        :type: str
        """
        if destination_code is not None and len(destination_code) > 3:
            raise ValueError(
                "Invalid value for `destination_code`, length must be less than or equal to `3`"
            )  # noqa: E501
        if destination_code is not None and len(destination_code) < 3:
            raise ValueError(
                "Invalid value for `destination_code`, length must be greater than or equal to `3`"
            )  # noqa: E501

        self._destination_code = destination_code

    @property
    def fare_basis_code(self):
        """Gets the fare_basis_code of this Flight.  # noqa: E501

        Fare basis code  # noqa: E501

        :return: The fare_basis_code of this Flight.  # noqa: E501
        :rtype: str
        """
        return self._fare_basis_code

    @fare_basis_code.setter
    def fare_basis_code(self, fare_basis_code):
        """Sets the fare_basis_code of this Flight.

        Fare basis code  # noqa: E501

        :param fare_basis_code: The fare_basis_code of this Flight.  # noqa: E501
        :type: str
        """
        if fare_basis_code is not None and len(fare_basis_code) > 6:
            raise ValueError(
                "Invalid value for `fare_basis_code`, length must be less than or equal to `6`"
            )  # noqa: E501
        if fare_basis_code is not None and len(fare_basis_code) < 0:
            raise ValueError(
                "Invalid value for `fare_basis_code`, length must be greater than or equal to `0`"
            )  # noqa: E501

        self._fare_basis_code = fare_basis_code

    @property
    def index(self):
        """Gets the index of this Flight.  # noqa: E501

        Sequence number (index) of the flight, each index number must be unique in one flights section  # noqa: E501

        :return: The index of this Flight.  # noqa: E501
        :rtype: int
        """
        return self._index

    @index.setter
    def index(self, index):
        """Sets the index of this Flight.

        Sequence number (index) of the flight, each index number must be unique in one flights section  # noqa: E501

        :param index: The index of this Flight.  # noqa: E501
        :type: int
        """

        self._index = index

    @property
    def number(self):
        """Gets the number of this Flight.  # noqa: E501

        IATA or ICAO flight number  # noqa: E501

        :return: The number of this Flight.  # noqa: E501
        :rtype: str
        """
        return self._number

    @number.setter
    def number(self, number):
        """Sets the number of this Flight.

        IATA or ICAO flight number  # noqa: E501

        :param number: The number of this Flight.  # noqa: E501
        :type: str
        """
        if number is not None and len(number) > 5:
            raise ValueError(
                "Invalid value for `number`, length must be less than or equal to `5`"
            )  # noqa: E501
        if number is not None and len(number) < 0:
            raise ValueError(
                "Invalid value for `number`, length must be greater than or equal to `0`"
            )  # noqa: E501

        self._number = number

    @property
    def service_class_code(self):
        """Gets the service_class_code of this Flight.  # noqa: E501

        Code of service class  # noqa: E501

        :return: The service_class_code of this Flight.  # noqa: E501
        :rtype: int
        """
        return self._service_class_code

    @service_class_code.setter
    def service_class_code(self, service_class_code):
        """Sets the service_class_code of this Flight.

        Code of service class  # noqa: E501

        :param service_class_code: The service_class_code of this Flight.  # noqa: E501
        :type: int
        """

        self._service_class_code = service_class_code

    @property
    def stop_over_code(self):
        """Gets the stop_over_code of this Flight.  # noqa: E501

        Stop over code  # noqa: E501

        :return: The stop_over_code of this Flight.  # noqa: E501
        :rtype: str
        """
        return self._stop_over_code

    @stop_over_code.setter
    def stop_over_code(self, stop_over_code):
        """Sets the stop_over_code of this Flight.

        Stop over code  # noqa: E501

        :param stop_over_code: The stop_over_code of this Flight.  # noqa: E501
        :type: str
        """
        if stop_over_code is not None and len(stop_over_code) > 1:
            raise ValueError(
                "Invalid value for `stop_over_code`, length must be less than or equal to `1`"
            )  # noqa: E501
        if stop_over_code is not None and len(stop_over_code) < 1:
            raise ValueError(
                "Invalid value for `stop_over_code`, length must be greater than or equal to `1`"
            )  # noqa: E501

        self._stop_over_code = stop_over_code

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(Flight, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Flight):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class PlanUpdateRequestPlanData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {"name_to": "str", "status_to": "str"}

    attribute_map = {"name_to": "name_to", "status_to": "status_to"}

    def __init__(self, name_to=None, status_to=None):  # noqa: E501
        """PlanUpdateRequestPlanData - a model defined in Swagger"""  # noqa: E501

        self._name_to = None
        self._status_to = None
        self.discriminator = None

        if name_to is not None:
            self.name_to = name_to
        if status_to is not None:
            self.status_to = status_to

    @property
    def name_to(self):
        """Gets the name_to of this PlanUpdateRequestPlanData.  # noqa: E501

        New plan name - for RENAME operation only  # noqa: E501

        :return: The name_to of this PlanUpdateRequestPlanData.  # noqa: E501
        :rtype: str
        """
        return self._name_to

    @name_to.setter
    def name_to(self, name_to):
        """Sets the name_to of this PlanUpdateRequestPlanData.

        New plan name - for RENAME operation only  # noqa: E501

        :param name_to: The name_to of this PlanUpdateRequestPlanData.  # noqa: E501
        :type: str
        """
        if name_to is not None and len(name_to) > 25:
            raise ValueError(
                "Invalid value for `name_to`, length must be less than or equal to `25`"
            )  # noqa: E501
        if name_to is not None and len(name_to) < 0:
            raise ValueError(
                "Invalid value for `name_to`, length must be greater than or equal to `0`"
            )  # noqa: E501

        self._name_to = name_to

    class StatusTo(object):
        ACTIVE = "ACTIVE"
        INACTIVE = "INACTIVE"

    @property
    def status_to(self):
        """Gets the status_to of this PlanUpdateRequestPlanData.  # noqa: E501

        New state of plan (ACTIVE or INACTIVE) - for CHANGE_STATUS operation only  # noqa: E501

        :return: The status_to of this PlanUpdateRequestPlanData.  # noqa: E501
        :rtype: str
        """
        return self._status_to

    @status_to.setter
    def status_to(self, status_to):
        """Sets the status_to of this PlanUpdateRequestPlanData.

        New state of plan (ACTIVE or INACTIVE) - for CHANGE_STATUS operation only  # noqa: E501

        :param status_to: The status_to of this PlanUpdateRequestPlanData.  # noqa: E501
        :type: str
        """
        allowed_values = ["ACTIVE", "INACTIVE"]  # noqa: E501
        if status_to not in allowed_values:
            raise ValueError(
                "Invalid value for `status_to` ({0}), must be one of {1}".format(  # noqa: E501
                    status_to, allowed_values
                )
            )

        self._status_to = status_to

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(PlanUpdateRequestPlanData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PlanUpdateRequestPlanData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cardpay.model.plan import Plan  # noqa: F401,E501


class ScheduledData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "dynamic_descriptor": "str",
        "generate_token": "bool",
        "initial_amount": "float",
        "initiator": "str",
        "note": "str",
        "plan": "Plan",
        "subscription_start": "datetime",
        "trans_type": "str",
    }

    attribute_map = {
        "dynamic_descriptor": "dynamic_descriptor",
        "generate_token": "generate_token",
        "initial_amount": "initial_amount",
        "initiator": "initiator",
        "note": "note",
        "plan": "plan",
        "subscription_start": "subscription_start",
        "trans_type": "trans_type",
    }

    def __init__(
        self,
        dynamic_descriptor=None,
        generate_token=None,
        initial_amount=None,
        initiator=None,
        note=None,
        plan=None,
        subscription_start=None,
        trans_type=None,
    ):  # noqa: E501
        """ScheduledData - a model defined in Swagger"""  # noqa: E501

        self._dynamic_descriptor = None
        self._generate_token = None
        self._initial_amount = None
        self._initiator = None
        self._note = None
        self._plan = None
        self._subscription_start = None
        self._trans_type = None
        self.discriminator = None

        if dynamic_descriptor is not None:
            self.dynamic_descriptor = dynamic_descriptor
        if generate_token is not None:
            self.generate_token = generate_token
        if initial_amount is not None:
            self.initial_amount = initial_amount
        self.initiator = initiator
        if note is not None:
            self.note = note
        if plan is not None:
            self.plan = plan
        if subscription_start is not None:
            self.subscription_start = subscription_start
        if trans_type is not None:
            self.trans_type = trans_type

    @property
    def dynamic_descriptor(self):
        """Gets the dynamic_descriptor of this ScheduledData.  # noqa: E501

        Short description of the service or product, must be enabled by CardPay manager to be used.  # noqa: E501

        :return: The dynamic_descriptor of this ScheduledData.  # noqa: E501
        :rtype: str
        """
        return self._dynamic_descriptor

    @dynamic_descriptor.setter
    def dynamic_descriptor(self, dynamic_descriptor):
        """Sets the dynamic_descriptor of this ScheduledData.

        Short description of the service or product, must be enabled by CardPay manager to be used.  # noqa: E501

        :param dynamic_descriptor: The dynamic_descriptor of this ScheduledData.  # noqa: E501
        :type: str
        """
        if dynamic_descriptor is not None and len(dynamic_descriptor) > 25:
            raise ValueError(
                "Invalid value for `dynamic_descriptor`, length must be less than or equal to `25`"
            )  # noqa: E501
        if dynamic_descriptor is not None and len(dynamic_descriptor) < 0:
            raise ValueError(
                "Invalid value for `dynamic_descriptor`, length must be greater than or equal to `0`"
            )  # noqa: E501

        self._dynamic_descriptor = dynamic_descriptor

    @property
    def generate_token(self):
        """Gets the generate_token of this ScheduledData.  # noqa: E501

        This attribute can be received only in first recurring request. In all requests with recurring_id card.token can't be generated. If set to 'true', Card token will be generated and returned in GET response. Will be generated only for successful transactions (not for declined).  # noqa: E501

        :return: The generate_token of this ScheduledData.  # noqa: E501
        :rtype: bool
        """
        return self._generate_token

    @generate_token.setter
    def generate_token(self, generate_token):
        """Sets the generate_token of this ScheduledData.

        This attribute can be received only in first recurring request. In all requests with recurring_id card.token can't be generated. If set to 'true', Card token will be generated and returned in GET response. Will be generated only for successful transactions (not for declined).  # noqa: E501

        :param generate_token: The generate_token of this ScheduledData.  # noqa: E501
        :type: bool
        """

        self._generate_token = generate_token

    @property
    def initial_amount(self):
        """Gets the initial_amount of this ScheduledData.  # noqa: E501

        The amount of subscription initiated transaction in selected currency with dot as a decimal separator, must be less than 100 millions  # noqa: E501

        :return: The initial_amount of this ScheduledData.  # noqa: E501
        :rtype: float
        """
        return self._initial_amount

    @initial_amount.setter
    def initial_amount(self, initial_amount):
        """Sets the initial_amount of this ScheduledData.

        The amount of subscription initiated transaction in selected currency with dot as a decimal separator, must be less than 100 millions  # noqa: E501

        :param initial_amount: The initial_amount of this ScheduledData.  # noqa: E501
        :type: float
        """

        self._initial_amount = initial_amount

    @property
    def initiator(self):
        """Gets the initiator of this ScheduledData.  # noqa: E501

        Use `cit` for initiator attribute (cardholder initiated transaction).  # noqa: E501

        :return: The initiator of this ScheduledData.  # noqa: E501
        :rtype: str
        """
        return self._initiator

    @initiator.setter
    def initiator(self, initiator):
        """Sets the initiator of this ScheduledData.

        Use `cit` for initiator attribute (cardholder initiated transaction).  # noqa: E501

        :param initiator: The initiator of this ScheduledData.  # noqa: E501
        :type: str
        """
        if initiator is None:
            raise ValueError(
                "Invalid value for `initiator`, must not be `None`"
            )  # noqa: E501
        if initiator is not None and not re.search(r"mit|cit", initiator):  # noqa: E501
            raise ValueError(
                r"Invalid value for `initiator`, must be a follow pattern or equal to `/mit|cit/`"
            )  # noqa: E501

        self._initiator = initiator

    @property
    def note(self):
        """Gets the note of this ScheduledData.  # noqa: E501

        Note about the recurring that will not be displayed to customer.  # noqa: E501

        :return: The note of this ScheduledData.  # noqa: E501
        :rtype: str
        """
        return self._note

    @note.setter
    def note(self, note):
        """Sets the note of this ScheduledData.

        Note about the recurring that will not be displayed to customer.  # noqa: E501

        :param note: The note of this ScheduledData.  # noqa: E501
        :type: str
        """
        if note is not None and len(note) > 100:
            raise ValueError(
                "Invalid value for `note`, length must be less than or equal to `100`"
            )  # noqa: E501
        if note is not None and len(note) < 0:
            raise ValueError(
                "Invalid value for `note`, length must be greater than or equal to `0`"
            )  # noqa: E501

        self._note = note

    @property
    def plan(self):
        """Gets the plan of this ScheduledData.  # noqa: E501

        Plan data  # noqa: E501

        :return: The plan of this ScheduledData.  # noqa: E501
        :rtype: Plan
        """
        return self._plan

    @plan.setter
    def plan(self, plan):
        """Sets the plan of this ScheduledData.

        Plan data  # noqa: E501

        :param plan: The plan of this ScheduledData.  # noqa: E501
        :type: Plan
        """

        self._plan = plan

    @property
    def subscription_start(self):
        """Gets the subscription_start of this ScheduledData.  # noqa: E501

        The time in 'yyyy-MM-dd' format when subscription will actually become activated (grace period).Leave it empty to activate subscription at once without any grace period applied.  # noqa: E501

        :return: The subscription_start of this ScheduledData.  # noqa: E501
        :rtype: datetime
        """
        return self._subscription_start

    @subscription_start.setter
    def subscription_start(self, subscription_start):
        """Sets the subscription_start of this ScheduledData.

        The time in 'yyyy-MM-dd' format when subscription will actually become activated (grace period).Leave it empty to activate subscription at once without any grace period applied.  # noqa: E501

        :param subscription_start: The subscription_start of this ScheduledData.  # noqa: E501
        :type: datetime
        """

        self._subscription_start = subscription_start

    class TransType(object):
        _01 = "01"
        _03 = "03"
        _10 = "10"
        _11 = "11"
        _28 = "28"

    @property
    def trans_type(self):
        """Gets the trans_type of this ScheduledData.  # noqa: E501


        :return: The trans_type of this ScheduledData.  # noqa: E501
        :rtype: str
        """
        return self._trans_type

    @trans_type.setter
    def trans_type(self, trans_type):
        """Sets the trans_type of this ScheduledData.


        :param trans_type: The trans_type of this ScheduledData.  # noqa: E501
        :type: str
        """
        allowed_values = ["01", "03", "10", "11", "28"]  # noqa: E501
        if trans_type not in allowed_values:
            raise ValueError(
                "Invalid value for `trans_type` ({0}), must be one of {1}".format(  # noqa: E501
                    trans_type, allowed_values
                )
            )

        self._trans_type = trans_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(ScheduledData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ScheduledData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class RefundResponseRefundData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "amount": "float",
        "auth_code": "str",
        "created": "str",
        "currency": "str",
        "decline_code": "str",
        "decline_reason": "str",
        "id": "str",
        "is_3d": "bool",
        "rrn": "str",
        "status": "str",
    }

    attribute_map = {
        "amount": "amount",
        "auth_code": "auth_code",
        "created": "created",
        "currency": "currency",
        "decline_code": "decline_code",
        "decline_reason": "decline_reason",
        "id": "id",
        "is_3d": "is_3d",
        "rrn": "rrn",
        "status": "status",
    }

    def __init__(
        self,
        amount=None,
        auth_code=None,
        created=None,
        currency=None,
        decline_code=None,
        decline_reason=None,
        id=None,
        is_3d=None,
        rrn=None,
        status=None,
    ):  # noqa: E501
        """RefundResponseRefundData - a model defined in Swagger"""  # noqa: E501

        self._amount = None
        self._auth_code = None
        self._created = None
        self._currency = None
        self._decline_code = None
        self._decline_reason = None
        self._id = None
        self._is_3d = None
        self._rrn = None
        self._status = None
        self.discriminator = None

        self.amount = amount
        if auth_code is not None:
            self.auth_code = auth_code
        self.created = created
        self.currency = currency
        if decline_code is not None:
            self.decline_code = decline_code
        if decline_reason is not None:
            self.decline_reason = decline_reason
        self.id = id
        if is_3d is not None:
            self.is_3d = is_3d
        if rrn is not None:
            self.rrn = rrn
        self.status = status

    @property
    def amount(self):
        """Gets the amount of this RefundResponseRefundData.  # noqa: E501

        Refund transaction amount  # noqa: E501

        :return: The amount of this RefundResponseRefundData.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this RefundResponseRefundData.

        Refund transaction amount  # noqa: E501

        :param amount: The amount of this RefundResponseRefundData.  # noqa: E501
        :type: float
        """
        if amount is None:
            raise ValueError(
                "Invalid value for `amount`, must not be `None`"
            )  # noqa: E501

        self._amount = amount

    @property
    def auth_code(self):
        """Gets the auth_code of this RefundResponseRefundData.  # noqa: E501

        Authorization code, provided by bank *(for BANKCARD payment method only)*  # noqa: E501

        :return: The auth_code of this RefundResponseRefundData.  # noqa: E501
        :rtype: str
        """
        return self._auth_code

    @auth_code.setter
    def auth_code(self, auth_code):
        """Sets the auth_code of this RefundResponseRefundData.

        Authorization code, provided by bank *(for BANKCARD payment method only)*  # noqa: E501

        :param auth_code: The auth_code of this RefundResponseRefundData.  # noqa: E501
        :type: str
        """

        self._auth_code = auth_code

    @property
    def created(self):
        """Gets the created of this RefundResponseRefundData.  # noqa: E501

        Date and time when this refund was created, [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format  # noqa: E501

        :return: The created of this RefundResponseRefundData.  # noqa: E501
        :rtype: str
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this RefundResponseRefundData.

        Date and time when this refund was created, [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format  # noqa: E501

        :param created: The created of this RefundResponseRefundData.  # noqa: E501
        :type: str
        """
        if created is None:
            raise ValueError(
                "Invalid value for `created`, must not be `None`"
            )  # noqa: E501

        self._created = created

    @property
    def currency(self):
        """Gets the currency of this RefundResponseRefundData.  # noqa: E501

        Currency of refunded amount, [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217) currency code  # noqa: E501

        :return: The currency of this RefundResponseRefundData.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this RefundResponseRefundData.

        Currency of refunded amount, [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217) currency code  # noqa: E501

        :param currency: The currency of this RefundResponseRefundData.  # noqa: E501
        :type: str
        """
        if currency is None:
            raise ValueError(
                "Invalid value for `currency`, must not be `None`"
            )  # noqa: E501
        if currency is not None and len(currency) > 3:
            raise ValueError(
                "Invalid value for `currency`, length must be less than or equal to `3`"
            )  # noqa: E501
        if currency is not None and len(currency) < 3:
            raise ValueError(
                "Invalid value for `currency`, length must be greater than or equal to `3`"
            )  # noqa: E501

        self._currency = currency

    @property
    def decline_code(self):
        """Gets the decline_code of this RefundResponseRefundData.  # noqa: E501

        Refund decline code (only for `DECLINED` refund status)  # noqa: E501

        :return: The decline_code of this RefundResponseRefundData.  # noqa: E501
        :rtype: str
        """
        return self._decline_code

    @decline_code.setter
    def decline_code(self, decline_code):
        """Sets the decline_code of this RefundResponseRefundData.

        Refund decline code (only for `DECLINED` refund status)  # noqa: E501

        :param decline_code: The decline_code of this RefundResponseRefundData.  # noqa: E501
        :type: str
        """

        self._decline_code = decline_code

    @property
    def decline_reason(self):
        """Gets the decline_reason of this RefundResponseRefundData.  # noqa: E501

        Refund decline reason (only for `DECLINED` refund status)  # noqa: E501

        :return: The decline_reason of this RefundResponseRefundData.  # noqa: E501
        :rtype: str
        """
        return self._decline_reason

    @decline_reason.setter
    def decline_reason(self, decline_reason):
        """Sets the decline_reason of this RefundResponseRefundData.

        Refund decline reason (only for `DECLINED` refund status)  # noqa: E501

        :param decline_reason: The decline_reason of this RefundResponseRefundData.  # noqa: E501
        :type: str
        """

        self._decline_reason = decline_reason

    @property
    def id(self):
        """Gets the id of this RefundResponseRefundData.  # noqa: E501

        ID of the newly created refund in CardPay system  # noqa: E501

        :return: The id of this RefundResponseRefundData.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this RefundResponseRefundData.

        ID of the newly created refund in CardPay system  # noqa: E501

        :param id: The id of this RefundResponseRefundData.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def is_3d(self):
        """Gets the is_3d of this RefundResponseRefundData.  # noqa: E501

        Was 3-D Secure authentication made or not *(for BANKCARD payment method only)*  # noqa: E501

        :return: The is_3d of this RefundResponseRefundData.  # noqa: E501
        :rtype: bool
        """
        return self._is_3d

    @is_3d.setter
    def is_3d(self, is_3d):
        """Sets the is_3d of this RefundResponseRefundData.

        Was 3-D Secure authentication made or not *(for BANKCARD payment method only)*  # noqa: E501

        :param is_3d: The is_3d of this RefundResponseRefundData.  # noqa: E501
        :type: bool
        """

        self._is_3d = is_3d

    @property
    def rrn(self):
        """Gets the rrn of this RefundResponseRefundData.  # noqa: E501

        RRN (Retrieval Reference Number), supplied by the acquiring financial institution *(for BANKCARD payment method only)*  # noqa: E501

        :return: The rrn of this RefundResponseRefundData.  # noqa: E501
        :rtype: str
        """
        return self._rrn

    @rrn.setter
    def rrn(self, rrn):
        """Sets the rrn of this RefundResponseRefundData.

        RRN (Retrieval Reference Number), supplied by the acquiring financial institution *(for BANKCARD payment method only)*  # noqa: E501

        :param rrn: The rrn of this RefundResponseRefundData.  # noqa: E501
        :type: str
        """

        self._rrn = rrn

    class Status(object):
        NEW = "NEW"
        IN_PROGRESS = "IN_PROGRESS"
        DECLINED = "DECLINED"
        AUTHORIZED = "AUTHORIZED"
        COMPLETED = "COMPLETED"
        CANCELLED = "CANCELLED"
        REFUNDED = "REFUNDED"
        PARTIALLY_REFUNDED = "PARTIALLY_REFUNDED"
        VOIDED = "VOIDED"
        CHARGED_BACK = "CHARGED_BACK"
        CHARGEBACK_RESOLVED = "CHARGEBACK_RESOLVED"

    @property
    def status(self):
        """Gets the status of this RefundResponseRefundData.  # noqa: E501

        Refund status in CardPay system  # noqa: E501

        :return: The status of this RefundResponseRefundData.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this RefundResponseRefundData.

        Refund status in CardPay system  # noqa: E501

        :param status: The status of this RefundResponseRefundData.  # noqa: E501
        :type: str
        """
        if status is None:
            raise ValueError(
                "Invalid value for `status`, must not be `None`"
            )  # noqa: E501
        allowed_values = [
            "NEW",
            "IN_PROGRESS",
            "DECLINED",
            "AUTHORIZED",
            "COMPLETED",
            "CANCELLED",
            "REFUNDED",
            "PARTIALLY_REFUNDED",
            "VOIDED",
            "CHARGED_BACK",
            "CHARGEBACK_RESOLVED",
        ]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}".format(  # noqa: E501
                    status, allowed_values
                )
            )

        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(RefundResponseRefundData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RefundResponseRefundData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ReturnUrls(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "cancel_url": "str",
        "decline_url": "str",
        "inprocess_url": "str",
        "return_url": "str",
        "success_url": "str",
    }

    attribute_map = {
        "cancel_url": "cancel_url",
        "decline_url": "decline_url",
        "inprocess_url": "inprocess_url",
        "return_url": "return_url",
        "success_url": "success_url",
    }

    def __init__(
        self,
        cancel_url=None,
        decline_url=None,
        inprocess_url=None,
        return_url=None,
        success_url=None,
    ):  # noqa: E501
        """ReturnUrls - a model defined in Swagger"""  # noqa: E501

        self._cancel_url = None
        self._decline_url = None
        self._inprocess_url = None
        self._return_url = None
        self._success_url = None
        self.discriminator = None

        if cancel_url is not None:
            self.cancel_url = cancel_url
        if decline_url is not None:
            self.decline_url = decline_url
        if inprocess_url is not None:
            self.inprocess_url = inprocess_url
        if return_url is not None:
            self.return_url = return_url
        if success_url is not None:
            self.success_url = success_url

    @property
    def cancel_url(self):
        """Gets the cancel_url of this ReturnUrls.  # noqa: E501

        Overrides default cancel URL only  # noqa: E501

        :return: The cancel_url of this ReturnUrls.  # noqa: E501
        :rtype: str
        """
        return self._cancel_url

    @cancel_url.setter
    def cancel_url(self, cancel_url):
        """Sets the cancel_url of this ReturnUrls.

        Overrides default cancel URL only  # noqa: E501

        :param cancel_url: The cancel_url of this ReturnUrls.  # noqa: E501
        :type: str
        """

        self._cancel_url = cancel_url

    @property
    def decline_url(self):
        """Gets the decline_url of this ReturnUrls.  # noqa: E501

        Overrides default decline URL only  # noqa: E501

        :return: The decline_url of this ReturnUrls.  # noqa: E501
        :rtype: str
        """
        return self._decline_url

    @decline_url.setter
    def decline_url(self, decline_url):
        """Sets the decline_url of this ReturnUrls.

        Overrides default decline URL only  # noqa: E501

        :param decline_url: The decline_url of this ReturnUrls.  # noqa: E501
        :type: str
        """

        self._decline_url = decline_url

    @property
    def inprocess_url(self):
        """Gets the inprocess_url of this ReturnUrls.  # noqa: E501

        Special URL for In process status of transaction  # noqa: E501

        :return: The inprocess_url of this ReturnUrls.  # noqa: E501
        :rtype: str
        """
        return self._inprocess_url

    @inprocess_url.setter
    def inprocess_url(self, inprocess_url):
        """Sets the inprocess_url of this ReturnUrls.

        Special URL for In process status of transaction  # noqa: E501

        :param inprocess_url: The inprocess_url of this ReturnUrls.  # noqa: E501
        :type: str
        """

        self._inprocess_url = inprocess_url

    @property
    def return_url(self):
        """Gets the return_url of this ReturnUrls.  # noqa: E501

        Overrides default success URL and cancel URL. return_url can be used separately or together with other URL parameters  # noqa: E501

        :return: The return_url of this ReturnUrls.  # noqa: E501
        :rtype: str
        """
        return self._return_url

    @return_url.setter
    def return_url(self, return_url):
        """Sets the return_url of this ReturnUrls.

        Overrides default success URL and cancel URL. return_url can be used separately or together with other URL parameters  # noqa: E501

        :param return_url: The return_url of this ReturnUrls.  # noqa: E501
        :type: str
        """

        self._return_url = return_url

    @property
    def success_url(self):
        """Gets the success_url of this ReturnUrls.  # noqa: E501

        Overrides default success URL only  # noqa: E501

        :return: The success_url of this ReturnUrls.  # noqa: E501
        :rtype: str
        """
        return self._success_url

    @success_url.setter
    def success_url(self, success_url):
        """Sets the success_url of this ReturnUrls.

        Overrides default success URL only  # noqa: E501

        :param success_url: The success_url of this ReturnUrls.  # noqa: E501
        :type: str
        """

        self._success_url = success_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(ReturnUrls, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ReturnUrls):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from cardpay.api_client import ApiClient


class AuthApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def obtain_tokens(self, grant_type, **kwargs):  # noqa: E501
        """Get authorization token  # noqa: E501

        :param str grant_type: Token request credentials representation (required)
        :param str password: Terminal password value (only for [password] grant type)
        :param str refresh_token: Refresh token string (only for [refresh_token] grant type)
        :param str terminal_code: Terminal code value
        :return: ApiTokens
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True

        (data) = self.obtain_tokens_with_http_info(grant_type, **kwargs)  # noqa: E501
        return data

    def obtain_tokens_with_http_info(self, grant_type, **kwargs):  # noqa: E501
        """Get authorization token  # noqa: E501

        :param str grant_type: Token request credentials representation (required)
        :param str password: Terminal password value (only for [password] grant type)
        :param str refresh_token: Refresh token string (only for [refresh_token] grant type)
        :param str terminal_code: Terminal code value
        :return: ApiTokens
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = [
            "grant_type",
            "password",
            "refresh_token",
            "terminal_code",
        ]  # noqa: E501
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method obtain_tokens" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'grant_type' is set
        if "grant_type" not in params or params["grant_type"] is None:
            raise ValueError(
                "Missing the required parameter `grant_type` when calling `obtain_tokens`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if "grant_type" in params:
            form_params.append(("grant_type", params["grant_type"]))  # noqa: E501
        if "password" in params:
            form_params.append(("password", params["password"]))  # noqa: E501
        if "refresh_token" in params:
            form_params.append(("refresh_token", params["refresh_token"]))  # noqa: E501
        if "terminal_code" in params:
            form_params.append(("terminal_code", params["terminal_code"]))  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501
        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/x-www-form-urlencoded"]
        )  # noqa: E501

        return self.api_client.call_api(
            "/api/auth/token",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="ApiTokens",  # noqa: E501
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cardpay.model.claim_response_subscription_data import (
    ClaimResponseSubscriptionData,
)  # noqa: F401,E501


class ChangeSubscriptionStatusClaimResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "created": "datetime",
        "details": "str",
        "id": "str",
        "status": "str",
        "subscription_data": "ClaimResponseSubscriptionData",
        "updated": "datetime",
    }

    attribute_map = {
        "created": "created",
        "details": "details",
        "id": "id",
        "status": "status",
        "subscription_data": "subscription_data",
        "updated": "updated",
    }

    def __init__(
        self,
        created=None,
        details=None,
        id=None,
        status=None,
        subscription_data=None,
        updated=None,
    ):  # noqa: E501
        """ChangeSubscriptionStatusClaimResponse - a model defined in Swagger"""  # noqa: E501

        self._created = None
        self._details = None
        self._id = None
        self._status = None
        self._subscription_data = None
        self._updated = None
        self.discriminator = None

        self.created = created
        self.details = details
        self.id = id
        self.status = status
        if subscription_data is not None:
            self.subscription_data = subscription_data
        self.updated = updated

    @property
    def created(self):
        """Gets the created of this ChangeSubscriptionStatusClaimResponse.  # noqa: E501

        Creation time, [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format.  # noqa: E501

        :return: The created of this ChangeSubscriptionStatusClaimResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this ChangeSubscriptionStatusClaimResponse.

        Creation time, [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format.  # noqa: E501

        :param created: The created of this ChangeSubscriptionStatusClaimResponse.  # noqa: E501
        :type: datetime
        """
        if created is None:
            raise ValueError(
                "Invalid value for `created`, must not be `None`"
            )  # noqa: E501

        self._created = created

    @property
    def details(self):
        """Gets the details of this ChangeSubscriptionStatusClaimResponse.  # noqa: E501

        Change claim details, errors etc.  # noqa: E501

        :return: The details of this ChangeSubscriptionStatusClaimResponse.  # noqa: E501
        :rtype: str
        """
        return self._details

    @details.setter
    def details(self, details):
        """Sets the details of this ChangeSubscriptionStatusClaimResponse.

        Change claim details, errors etc.  # noqa: E501

        :param details: The details of this ChangeSubscriptionStatusClaimResponse.  # noqa: E501
        :type: str
        """
        if details is None:
            raise ValueError(
                "Invalid value for `details`, must not be `None`"
            )  # noqa: E501

        self._details = details

    @property
    def id(self):
        """Gets the id of this ChangeSubscriptionStatusClaimResponse.  # noqa: E501

        ID of claim  # noqa: E501

        :return: The id of this ChangeSubscriptionStatusClaimResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ChangeSubscriptionStatusClaimResponse.

        ID of claim  # noqa: E501

        :param id: The id of this ChangeSubscriptionStatusClaimResponse.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    class Status(object):
        IN_PROCESS = "IN_PROCESS"
        STOPPED = "STOPPED"
        COMPLETED = "COMPLETED"

    @property
    def status(self):
        """Gets the status of this ChangeSubscriptionStatusClaimResponse.  # noqa: E501

        Status of claim: `IN_PROCESS` - claim is in queue to being processed `STOPPED` - claim failed to be processed `COMPLETED` - claim successfully processed  # noqa: E501

        :return: The status of this ChangeSubscriptionStatusClaimResponse.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ChangeSubscriptionStatusClaimResponse.

        Status of claim: `IN_PROCESS` - claim is in queue to being processed `STOPPED` - claim failed to be processed `COMPLETED` - claim successfully processed  # noqa: E501

        :param status: The status of this ChangeSubscriptionStatusClaimResponse.  # noqa: E501
        :type: str
        """
        if status is None:
            raise ValueError(
                "Invalid value for `status`, must not be `None`"
            )  # noqa: E501
        allowed_values = ["IN_PROCESS", "STOPPED", "COMPLETED"]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}".format(  # noqa: E501
                    status, allowed_values
                )
            )

        self._status = status

    @property
    def subscription_data(self):
        """Gets the subscription_data of this ChangeSubscriptionStatusClaimResponse.  # noqa: E501

        Subscription data  # noqa: E501

        :return: The subscription_data of this ChangeSubscriptionStatusClaimResponse.  # noqa: E501
        :rtype: ClaimResponseSubscriptionData
        """
        return self._subscription_data

    @subscription_data.setter
    def subscription_data(self, subscription_data):
        """Sets the subscription_data of this ChangeSubscriptionStatusClaimResponse.

        Subscription data  # noqa: E501

        :param subscription_data: The subscription_data of this ChangeSubscriptionStatusClaimResponse.  # noqa: E501
        :type: ClaimResponseSubscriptionData
        """

        self._subscription_data = subscription_data

    @property
    def updated(self):
        """Gets the updated of this ChangeSubscriptionStatusClaimResponse.  # noqa: E501

        Time when claim got the new status, [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format.  # noqa: E501

        :return: The updated of this ChangeSubscriptionStatusClaimResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._updated

    @updated.setter
    def updated(self, updated):
        """Sets the updated of this ChangeSubscriptionStatusClaimResponse.

        Time when claim got the new status, [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format.  # noqa: E501

        :param updated: The updated of this ChangeSubscriptionStatusClaimResponse.  # noqa: E501
        :type: datetime
        """
        if updated is None:
            raise ValueError(
                "Invalid value for `updated`, must not be `None`"
            )  # noqa: E501

        self._updated = updated

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(ChangeSubscriptionStatusClaimResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ChangeSubscriptionStatusClaimResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class FilingRecurringData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "currency": "str",
        "dynamic_descriptor": "str",
        "initiator": "str",
        "note": "str",
        "trans_type": "str",
    }

    attribute_map = {
        "currency": "currency",
        "dynamic_descriptor": "dynamic_descriptor",
        "initiator": "initiator",
        "note": "note",
        "trans_type": "trans_type",
    }

    def __init__(
        self,
        currency=None,
        dynamic_descriptor=None,
        initiator=None,
        note=None,
        trans_type=None,
    ):  # noqa: E501
        """FilingRecurringData - a model defined in Swagger"""  # noqa: E501

        self._currency = None
        self._dynamic_descriptor = None
        self._initiator = None
        self._note = None
        self._trans_type = None
        self.discriminator = None

        if currency is not None:
            self.currency = currency
        if dynamic_descriptor is not None:
            self.dynamic_descriptor = dynamic_descriptor
        if initiator is not None:
            self.initiator = initiator
        if note is not None:
            self.note = note
        if trans_type is not None:
            self.trans_type = trans_type

    @property
    def currency(self):
        """Gets the currency of this FilingRecurringData.  # noqa: E501

        [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217) currency code  # noqa: E501

        :return: The currency of this FilingRecurringData.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this FilingRecurringData.

        [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217) currency code  # noqa: E501

        :param currency: The currency of this FilingRecurringData.  # noqa: E501
        :type: str
        """

        self._currency = currency

    @property
    def dynamic_descriptor(self):
        """Gets the dynamic_descriptor of this FilingRecurringData.  # noqa: E501

        Short description of the service or product, must be enabled by CardPay manager to be used  # noqa: E501

        :return: The dynamic_descriptor of this FilingRecurringData.  # noqa: E501
        :rtype: str
        """
        return self._dynamic_descriptor

    @dynamic_descriptor.setter
    def dynamic_descriptor(self, dynamic_descriptor):
        """Sets the dynamic_descriptor of this FilingRecurringData.

        Short description of the service or product, must be enabled by CardPay manager to be used  # noqa: E501

        :param dynamic_descriptor: The dynamic_descriptor of this FilingRecurringData.  # noqa: E501
        :type: str
        """
        if dynamic_descriptor is not None and len(dynamic_descriptor) > 25:
            raise ValueError(
                "Invalid value for `dynamic_descriptor`, length must be less than or equal to `25`"
            )  # noqa: E501
        if dynamic_descriptor is not None and len(dynamic_descriptor) < 0:
            raise ValueError(
                "Invalid value for `dynamic_descriptor`, length must be greater than or equal to `0`"
            )  # noqa: E501

        self._dynamic_descriptor = dynamic_descriptor

    @property
    def initiator(self):
        """Gets the initiator of this FilingRecurringData.  # noqa: E501

        Can be only `cit` (cardholder initiated transaction)  # noqa: E501

        :return: The initiator of this FilingRecurringData.  # noqa: E501
        :rtype: str
        """
        return self._initiator

    @initiator.setter
    def initiator(self, initiator):
        """Sets the initiator of this FilingRecurringData.

        Can be only `cit` (cardholder initiated transaction)  # noqa: E501

        :param initiator: The initiator of this FilingRecurringData.  # noqa: E501
        :type: str
        """
        if initiator is not None and not re.search(r"cit", initiator):  # noqa: E501
            raise ValueError(
                r"Invalid value for `initiator`, must be a follow pattern or equal to `/cit/`"
            )  # noqa: E501

        self._initiator = initiator

    @property
    def note(self):
        """Gets the note of this FilingRecurringData.  # noqa: E501

        Note about the transaction that will not be displayed to Customer  # noqa: E501

        :return: The note of this FilingRecurringData.  # noqa: E501
        :rtype: str
        """
        return self._note

    @note.setter
    def note(self, note):
        """Sets the note of this FilingRecurringData.

        Note about the transaction that will not be displayed to Customer  # noqa: E501

        :param note: The note of this FilingRecurringData.  # noqa: E501
        :type: str
        """
        if note is not None and len(note) > 100:
            raise ValueError(
                "Invalid value for `note`, length must be less than or equal to `100`"
            )  # noqa: E501
        if note is not None and len(note) < 0:
            raise ValueError(
                "Invalid value for `note`, length must be greater than or equal to `0`"
            )  # noqa: E501

        self._note = note

    class TransType(object):
        _01 = "01"
        _03 = "03"
        _10 = "10"
        _11 = "11"
        _28 = "28"

    @property
    def trans_type(self):
        """Gets the trans_type of this FilingRecurringData.  # noqa: E501


        :return: The trans_type of this FilingRecurringData.  # noqa: E501
        :rtype: str
        """
        return self._trans_type

    @trans_type.setter
    def trans_type(self, trans_type):
        """Sets the trans_type of this FilingRecurringData.


        :param trans_type: The trans_type of this FilingRecurringData.  # noqa: E501
        :type: str
        """
        allowed_values = ["01", "03", "10", "11", "28"]  # noqa: E501
        if trans_type not in allowed_values:
            raise ValueError(
                "Invalid value for `trans_type` ({0}), must be one of {1}".format(  # noqa: E501
                    trans_type, allowed_values
                )
            )

        self._trans_type = trans_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(FilingRecurringData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FilingRecurringData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class PaymentResponseCardAccount(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "acct_type": "str",
        "expiration": "str",
        "holder": "str",
        "issuing_country_code": "str",
        "masked_pan": "str",
        "token": "str",
    }

    attribute_map = {
        "acct_type": "acct_type",
        "expiration": "expiration",
        "holder": "holder",
        "issuing_country_code": "issuing_country_code",
        "masked_pan": "masked_pan",
        "token": "token",
    }

    def __init__(
        self,
        acct_type=None,
        expiration=None,
        holder=None,
        issuing_country_code=None,
        masked_pan=None,
        token=None,
    ):  # noqa: E501
        """PaymentResponseCardAccount - a model defined in Swagger"""  # noqa: E501

        self._acct_type = None
        self._expiration = None
        self._holder = None
        self._issuing_country_code = None
        self._masked_pan = None
        self._token = None
        self.discriminator = None

        if acct_type is not None:
            self.acct_type = acct_type
        if expiration is not None:
            self.expiration = expiration
        if holder is not None:
            self.holder = holder
        if issuing_country_code is not None:
            self.issuing_country_code = issuing_country_code
        if masked_pan is not None:
            self.masked_pan = masked_pan
        if token is not None:
            self.token = token

    class AcctType(object):
        _01 = "01"
        _02 = "02"
        _03 = "03"

    @property
    def acct_type(self):
        """Gets the acct_type of this PaymentResponseCardAccount.  # noqa: E501


        :return: The acct_type of this PaymentResponseCardAccount.  # noqa: E501
        :rtype: str
        """
        return self._acct_type

    @acct_type.setter
    def acct_type(self, acct_type):
        """Sets the acct_type of this PaymentResponseCardAccount.


        :param acct_type: The acct_type of this PaymentResponseCardAccount.  # noqa: E501
        :type: str
        """
        allowed_values = ["01", "02", "03"]  # noqa: E501
        if acct_type not in allowed_values:
            raise ValueError(
                "Invalid value for `acct_type` ({0}), must be one of {1}".format(  # noqa: E501
                    acct_type, allowed_values
                )
            )

        self._acct_type = acct_type

    @property
    def expiration(self):
        """Gets the expiration of this PaymentResponseCardAccount.  # noqa: E501

        Customer’s card expiration date. Format: `mm/yyyy`  # noqa: E501

        :return: The expiration of this PaymentResponseCardAccount.  # noqa: E501
        :rtype: str
        """
        return self._expiration

    @expiration.setter
    def expiration(self, expiration):
        """Sets the expiration of this PaymentResponseCardAccount.

        Customer’s card expiration date. Format: `mm/yyyy`  # noqa: E501

        :param expiration: The expiration of this PaymentResponseCardAccount.  # noqa: E501
        :type: str
        """

        self._expiration = expiration

    @property
    def holder(self):
        """Gets the holder of this PaymentResponseCardAccount.  # noqa: E501

        Customer's cardholder name. Any valid cardholder name. Not present by default, ask CardPay manager to enable it if needed.  # noqa: E501

        :return: The holder of this PaymentResponseCardAccount.  # noqa: E501
        :rtype: str
        """
        return self._holder

    @holder.setter
    def holder(self, holder):
        """Sets the holder of this PaymentResponseCardAccount.

        Customer's cardholder name. Any valid cardholder name. Not present by default, ask CardPay manager to enable it if needed.  # noqa: E501

        :param holder: The holder of this PaymentResponseCardAccount.  # noqa: E501
        :type: str
        """

        self._holder = holder

    @property
    def issuing_country_code(self):
        """Gets the issuing_country_code of this PaymentResponseCardAccount.  # noqa: E501

        Country code of issuing card country  # noqa: E501

        :return: The issuing_country_code of this PaymentResponseCardAccount.  # noqa: E501
        :rtype: str
        """
        return self._issuing_country_code

    @issuing_country_code.setter
    def issuing_country_code(self, issuing_country_code):
        """Sets the issuing_country_code of this PaymentResponseCardAccount.

        Country code of issuing card country  # noqa: E501

        :param issuing_country_code: The issuing_country_code of this PaymentResponseCardAccount.  # noqa: E501
        :type: str
        """

        self._issuing_country_code = issuing_country_code

    @property
    def masked_pan(self):
        """Gets the masked_pan of this PaymentResponseCardAccount.  # noqa: E501

        Masked PAN (shows first 6 digits and 4 last digits)  # noqa: E501

        :return: The masked_pan of this PaymentResponseCardAccount.  # noqa: E501
        :rtype: str
        """
        return self._masked_pan

    @masked_pan.setter
    def masked_pan(self, masked_pan):
        """Sets the masked_pan of this PaymentResponseCardAccount.

        Masked PAN (shows first 6 digits and 4 last digits)  # noqa: E501

        :param masked_pan: The masked_pan of this PaymentResponseCardAccount.  # noqa: E501
        :type: str
        """

        self._masked_pan = masked_pan

    @property
    def token(self):
        """Gets the token of this PaymentResponseCardAccount.  # noqa: E501

        Generated card token value. Token can be returned only for successful transactions (not for declined transactions). For payment: PaymentResponsePaymentData, for recurring: RecurringResponseRecurringData.   # noqa: E501

        :return: The token of this PaymentResponseCardAccount.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this PaymentResponseCardAccount.

        Generated card token value. Token can be returned only for successful transactions (not for declined transactions). For payment: PaymentResponsePaymentData, for recurring: RecurringResponseRecurringData.   # noqa: E501

        :param token: The token of this PaymentResponseCardAccount.  # noqa: E501
        :type: str
        """

        self._token = token

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(PaymentResponseCardAccount, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PaymentResponseCardAccount):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class BankCardPayoutData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "amount": "float",
        "created": "str",
        "currency": "str",
        "decline_code": "str",
        "decline_reason": "str",
        "id": "str",
        "note": "str",
        "rrn": "str",
        "status": "str",
    }

    attribute_map = {
        "amount": "amount",
        "created": "created",
        "currency": "currency",
        "decline_code": "decline_code",
        "decline_reason": "decline_reason",
        "id": "id",
        "note": "note",
        "rrn": "rrn",
        "status": "status",
    }

    def __init__(
        self,
        amount=None,
        created=None,
        currency=None,
        decline_code=None,
        decline_reason=None,
        id=None,
        note=None,
        rrn=None,
        status=None,
    ):  # noqa: E501
        """BankCardPayoutData - a model defined in Swagger"""  # noqa: E501

        self._amount = None
        self._created = None
        self._currency = None
        self._decline_code = None
        self._decline_reason = None
        self._id = None
        self._note = None
        self._rrn = None
        self._status = None
        self.discriminator = None

        self.amount = amount
        self.created = created
        self.currency = currency
        if decline_code is not None:
            self.decline_code = decline_code
        if decline_reason is not None:
            self.decline_reason = decline_reason
        self.id = id
        if note is not None:
            self.note = note
        if rrn is not None:
            self.rrn = rrn
        self.status = status

    @property
    def amount(self):
        """Gets the amount of this BankCardPayoutData.  # noqa: E501

        Payout amount  # noqa: E501

        :return: The amount of this BankCardPayoutData.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this BankCardPayoutData.

        Payout amount  # noqa: E501

        :param amount: The amount of this BankCardPayoutData.  # noqa: E501
        :type: float
        """
        if amount is None:
            raise ValueError(
                "Invalid value for `amount`, must not be `None`"
            )  # noqa: E501

        self._amount = amount

    @property
    def created(self):
        """Gets the created of this BankCardPayoutData.  # noqa: E501

        Date and time when this payout was created, [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format  # noqa: E501

        :return: The created of this BankCardPayoutData.  # noqa: E501
        :rtype: str
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this BankCardPayoutData.

        Date and time when this payout was created, [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format  # noqa: E501

        :param created: The created of this BankCardPayoutData.  # noqa: E501
        :type: str
        """
        if created is None:
            raise ValueError(
                "Invalid value for `created`, must not be `None`"
            )  # noqa: E501

        self._created = created

    @property
    def currency(self):
        """Gets the currency of this BankCardPayoutData.  # noqa: E501

        Payout currency ([ISO 4217](https://en.wikipedia.org/wiki/ISO_4217) format)  # noqa: E501

        :return: The currency of this BankCardPayoutData.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this BankCardPayoutData.

        Payout currency ([ISO 4217](https://en.wikipedia.org/wiki/ISO_4217) format)  # noqa: E501

        :param currency: The currency of this BankCardPayoutData.  # noqa: E501
        :type: str
        """
        if currency is None:
            raise ValueError(
                "Invalid value for `currency`, must not be `None`"
            )  # noqa: E501
        if currency is not None and len(currency) > 3:
            raise ValueError(
                "Invalid value for `currency`, length must be less than or equal to `3`"
            )  # noqa: E501
        if currency is not None and len(currency) < 3:
            raise ValueError(
                "Invalid value for `currency`, length must be greater than or equal to `3`"
            )  # noqa: E501

        self._currency = currency

    @property
    def decline_code(self):
        """Gets the decline_code of this BankCardPayoutData.  # noqa: E501

        Decline code (only in decline case)  # noqa: E501

        :return: The decline_code of this BankCardPayoutData.  # noqa: E501
        :rtype: str
        """
        return self._decline_code

    @decline_code.setter
    def decline_code(self, decline_code):
        """Sets the decline_code of this BankCardPayoutData.

        Decline code (only in decline case)  # noqa: E501

        :param decline_code: The decline_code of this BankCardPayoutData.  # noqa: E501
        :type: str
        """

        self._decline_code = decline_code

    @property
    def decline_reason(self):
        """Gets the decline_reason of this BankCardPayoutData.  # noqa: E501

        Bank's message about payout decline reason (only in decline case)  # noqa: E501

        :return: The decline_reason of this BankCardPayoutData.  # noqa: E501
        :rtype: str
        """
        return self._decline_reason

    @decline_reason.setter
    def decline_reason(self, decline_reason):
        """Sets the decline_reason of this BankCardPayoutData.

        Bank's message about payout decline reason (only in decline case)  # noqa: E501

        :param decline_reason: The decline_reason of this BankCardPayoutData.  # noqa: E501
        :type: str
        """

        self._decline_reason = decline_reason

    @property
    def id(self):
        """Gets the id of this BankCardPayoutData.  # noqa: E501

        CardPay's payout id  # noqa: E501

        :return: The id of this BankCardPayoutData.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BankCardPayoutData.

        CardPay's payout id  # noqa: E501

        :param id: The id of this BankCardPayoutData.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def note(self):
        """Gets the note of this BankCardPayoutData.  # noqa: E501

        Payout note  # noqa: E501

        :return: The note of this BankCardPayoutData.  # noqa: E501
        :rtype: str
        """
        return self._note

    @note.setter
    def note(self, note):
        """Sets the note of this BankCardPayoutData.

        Payout note  # noqa: E501

        :param note: The note of this BankCardPayoutData.  # noqa: E501
        :type: str
        """
        if note is not None and len(note) > 100:
            raise ValueError(
                "Invalid value for `note`, length must be less than or equal to `100`"
            )  # noqa: E501
        if note is not None and len(note) < 0:
            raise ValueError(
                "Invalid value for `note`, length must be greater than or equal to `0`"
            )  # noqa: E501

        self._note = note

    @property
    def rrn(self):
        """Gets the rrn of this BankCardPayoutData.  # noqa: E501

        RRN (Retrieval Reference Number), supplied by the acquiring financial institution *(for BANKCARD method only)*  # noqa: E501

        :return: The rrn of this BankCardPayoutData.  # noqa: E501
        :rtype: str
        """
        return self._rrn

    @rrn.setter
    def rrn(self, rrn):
        """Sets the rrn of this BankCardPayoutData.

        RRN (Retrieval Reference Number), supplied by the acquiring financial institution *(for BANKCARD method only)*  # noqa: E501

        :param rrn: The rrn of this BankCardPayoutData.  # noqa: E501
        :type: str
        """

        self._rrn = rrn

    class Status(object):
        NEW = "NEW"
        IN_PROGRESS = "IN_PROGRESS"
        DECLINED = "DECLINED"
        AUTHORIZED = "AUTHORIZED"
        COMPLETED = "COMPLETED"
        CANCELLED = "CANCELLED"
        REFUNDED = "REFUNDED"
        PARTIALLY_REFUNDED = "PARTIALLY_REFUNDED"
        VOIDED = "VOIDED"
        CHARGED_BACK = "CHARGED_BACK"
        CHARGEBACK_RESOLVED = "CHARGEBACK_RESOLVED"

    @property
    def status(self):
        """Gets the status of this BankCardPayoutData.  # noqa: E501

        Current payout status  # noqa: E501

        :return: The status of this BankCardPayoutData.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this BankCardPayoutData.

        Current payout status  # noqa: E501

        :param status: The status of this BankCardPayoutData.  # noqa: E501
        :type: str
        """
        if status is None:
            raise ValueError(
                "Invalid value for `status`, must not be `None`"
            )  # noqa: E501
        allowed_values = [
            "NEW",
            "IN_PROGRESS",
            "DECLINED",
            "AUTHORIZED",
            "COMPLETED",
            "CANCELLED",
            "REFUNDED",
            "PARTIALLY_REFUNDED",
            "VOIDED",
            "CHARGED_BACK",
            "CHARGEBACK_RESOLVED",
        ]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}".format(  # noqa: E501
                    status, allowed_values
                )
            )

        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(BankCardPayoutData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BankCardPayoutData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cardpay.model.payout_request_living_address import (
    PayoutRequestLivingAddress,
)  # noqa: F401,E501


class PayoutRequestCustomer(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "document_number": "str",
        "document_type": "str",
        "email": "str",
        "first_name": "str",
        "full_name": "str",
        "id": "str",
        "last_name": "str",
        "living_address": "PayoutRequestLivingAddress",
        "phone": "str",
    }

    attribute_map = {
        "document_number": "document_number",
        "document_type": "document_type",
        "email": "email",
        "first_name": "first_name",
        "full_name": "full_name",
        "id": "id",
        "last_name": "last_name",
        "living_address": "living_address",
        "phone": "phone",
    }

    def __init__(
        self,
        document_number=None,
        document_type=None,
        email=None,
        first_name=None,
        full_name=None,
        id=None,
        last_name=None,
        living_address=None,
        phone=None,
    ):  # noqa: E501
        """PayoutRequestCustomer - a model defined in Swagger"""  # noqa: E501

        self._document_number = None
        self._document_type = None
        self._email = None
        self._first_name = None
        self._full_name = None
        self._id = None
        self._last_name = None
        self._living_address = None
        self._phone = None
        self.discriminator = None

        if document_number is not None:
            self.document_number = document_number
        if document_type is not None:
            self.document_type = document_type
        if email is not None:
            self.email = email
        if first_name is not None:
            self.first_name = first_name
        if full_name is not None:
            self.full_name = full_name
        if id is not None:
            self.id = id
        if last_name is not None:
            self.last_name = last_name
        if living_address is not None:
            self.living_address = living_address
        if phone is not None:
            self.phone = phone

    @property
    def document_number(self):
        """Gets the document_number of this PayoutRequestCustomer.  # noqa: E501

        Customer document number *(mandatory for 'Latin America' methods only)* For 'Latin America' is required for methods where country = AR, BR, CL, CO, PE, UY  # noqa: E501

        :return: The document_number of this PayoutRequestCustomer.  # noqa: E501
        :rtype: str
        """
        return self._document_number

    @document_number.setter
    def document_number(self, document_number):
        """Sets the document_number of this PayoutRequestCustomer.

        Customer document number *(mandatory for 'Latin America' methods only)* For 'Latin America' is required for methods where country = AR, BR, CL, CO, PE, UY  # noqa: E501

        :param document_number: The document_number of this PayoutRequestCustomer.  # noqa: E501
        :type: str
        """

        self._document_number = document_number

    @property
    def document_type(self):
        """Gets the document_type of this PayoutRequestCustomer.  # noqa: E501

        Customer document type *(mandatory for 'Latin America' methods only)* For 'Latin America' is required for methods where country = CO, PE  # noqa: E501

        :return: The document_type of this PayoutRequestCustomer.  # noqa: E501
        :rtype: str
        """
        return self._document_type

    @document_type.setter
    def document_type(self, document_type):
        """Sets the document_type of this PayoutRequestCustomer.

        Customer document type *(mandatory for 'Latin America' methods only)* For 'Latin America' is required for methods where country = CO, PE  # noqa: E501

        :param document_type: The document_type of this PayoutRequestCustomer.  # noqa: E501
        :type: str
        """

        self._document_type = document_type

    @property
    def email(self):
        """Gets the email of this PayoutRequestCustomer.  # noqa: E501

        Customer e-mail address *(mandatory for 'Latin America' methods only)* For 'Latin America' is required for methods where country = CO  # noqa: E501

        :return: The email of this PayoutRequestCustomer.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this PayoutRequestCustomer.

        Customer e-mail address *(mandatory for 'Latin America' methods only)* For 'Latin America' is required for methods where country = CO  # noqa: E501

        :param email: The email of this PayoutRequestCustomer.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def first_name(self):
        """Gets the first_name of this PayoutRequestCustomer.  # noqa: E501

        Customer first name *(mandatory for 'Latin America' methods only)*  # noqa: E501

        :return: The first_name of this PayoutRequestCustomer.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this PayoutRequestCustomer.

        Customer first name *(mandatory for 'Latin America' methods only)*  # noqa: E501

        :param first_name: The first_name of this PayoutRequestCustomer.  # noqa: E501
        :type: str
        """

        self._first_name = first_name

    @property
    def full_name(self):
        """Gets the full_name of this PayoutRequestCustomer.  # noqa: E501

        Customer full name. Mandatory for DIRECTBANKINGNGA methods only: For DIRECTBANKINGNGA: only for non NGN currency  # noqa: E501

        :return: The full_name of this PayoutRequestCustomer.  # noqa: E501
        :rtype: str
        """
        return self._full_name

    @full_name.setter
    def full_name(self, full_name):
        """Sets the full_name of this PayoutRequestCustomer.

        Customer full name. Mandatory for DIRECTBANKINGNGA methods only: For DIRECTBANKINGNGA: only for non NGN currency  # noqa: E501

        :param full_name: The full_name of this PayoutRequestCustomer.  # noqa: E501
        :type: str
        """

        self._full_name = full_name

    @property
    def id(self):
        """Gets the id of this PayoutRequestCustomer.  # noqa: E501

        Customer id *(mandatory for WEBMONEY method only)*  # noqa: E501

        :return: The id of this PayoutRequestCustomer.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PayoutRequestCustomer.

        Customer id *(mandatory for WEBMONEY method only)*  # noqa: E501

        :param id: The id of this PayoutRequestCustomer.  # noqa: E501
        :type: str
        """
        if id is not None and len(id) > 256:
            raise ValueError(
                "Invalid value for `id`, length must be less than or equal to `256`"
            )  # noqa: E501
        if id is not None and len(id) < 0:
            raise ValueError(
                "Invalid value for `id`, length must be greater than or equal to `0`"
            )  # noqa: E501

        self._id = id

    @property
    def last_name(self):
        """Gets the last_name of this PayoutRequestCustomer.  # noqa: E501

        Customer last name *(mandatory for 'Latin America' methods only)* For 'Latin America' is required for methods where country = AR, BR, CO, MX, PE, UY  # noqa: E501

        :return: The last_name of this PayoutRequestCustomer.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this PayoutRequestCustomer.

        Customer last name *(mandatory for 'Latin America' methods only)* For 'Latin America' is required for methods where country = AR, BR, CO, MX, PE, UY  # noqa: E501

        :param last_name: The last_name of this PayoutRequestCustomer.  # noqa: E501
        :type: str
        """

        self._last_name = last_name

    @property
    def living_address(self):
        """Gets the living_address of this PayoutRequestCustomer.  # noqa: E501

        Customer address *(mandatory for 'Latin America' methods only)* For 'Latin America' is required for methods where country = CO  # noqa: E501

        :return: The living_address of this PayoutRequestCustomer.  # noqa: E501
        :rtype: PayoutRequestLivingAddress
        """
        return self._living_address

    @living_address.setter
    def living_address(self, living_address):
        """Sets the living_address of this PayoutRequestCustomer.

        Customer address *(mandatory for 'Latin America' methods only)* For 'Latin America' is required for methods where country = CO  # noqa: E501

        :param living_address: The living_address of this PayoutRequestCustomer.  # noqa: E501
        :type: PayoutRequestLivingAddress
        """

        self._living_address = living_address

    @property
    def phone(self):
        """Gets the phone of this PayoutRequestCustomer.  # noqa: E501

        Customer's phone number  # noqa: E501

        :return: The phone of this PayoutRequestCustomer.  # noqa: E501
        :rtype: str
        """
        return self._phone

    @phone.setter
    def phone(self, phone):
        """Sets the phone of this PayoutRequestCustomer.

        Customer's phone number  # noqa: E501

        :param phone: The phone of this PayoutRequestCustomer.  # noqa: E501
        :type: str
        """

        self._phone = phone

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(PayoutRequestCustomer, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PayoutRequestCustomer):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
